@@ -612,20 +612,20 @@ public:
     void setReflowLines(bool enable);
 
     /* Graphics display functions */
-    int addPlacement(QPixmap pixmap,
-                     int &rows,
-                     int &cols,
-                     int row = -1,
-                     int col = -1,
-                     bool scrolling = true,
-                     bool moveCursor = true,
-                     bool leaveText = false,
-                     int z = -1000,
-                     int id = -1,
-                     int pid = -1,
-                     qreal opacity = 1.0,
-                     int X = 0,
-                     int Y = 0);
+    void addPlacement(QPixmap pixmap,
+                      int &rows,
+                      int &cols,
+                      int row = -1,
+                      int col = -1,
+                      bool scrolling = true,
+                      int moveCursor = 1,
+                      bool leaveText = false,
+                      int z = -1000,
+                      int id = -1,
+                      int pid = -1,
+                      qreal opacity = 1.0,
+                      int X = 0,
+                      int Y = 0);
     TerminalGraphicsPlacement_t *getGraphicsPlacement(unsigned int i);
     void scrollUpVisiblePlacements(int n);
     void delPlacements(int = 'a', qint64 = 0, qint64 = -1, int = 0, int = 0, int = 0);
