@@ -8,10 +8,10 @@
 #define PROFILESETTINGS_H
 
 // Qt
-#include <QStyledItemDelegate>
-#include <QSet>
-#include <QKeySequenceEdit>
 #include <QExplicitlySharedDataPointer>
+#include <QKeySequenceEdit>
+#include <QSet>
+#include <QStyledItemDelegate>
 
 // KDE
 
@@ -23,7 +23,8 @@ class QItemSelection;
 class QStandardItem;
 class QStandardItemModel;
 
-namespace Konsole {
+namespace Konsole
+{
 class Profile;
 
 /**
@@ -53,10 +54,10 @@ public:
      */
     void setShortcutEditorVisible(bool visible);
 
-protected:
-
 private Q_SLOTS:
+    friend class MainWindow;
     void slotAccepted();
+
     void deleteSelected();
     void setSelectedAsDefault();
     void createProfile();
